@@ -2,7 +2,7 @@
                           ofxdump.cpp
                              -------------------
     copyright            : (C) 2002 by Benoit Grégoire
-    email                : bock@step.polymtl.ca
+    email                : benoitg@coeus.ca
 ***************************************************************************/
 /**@file
  * \brief Code for ofxdump utility.  C++ example code
@@ -29,6 +29,8 @@
  ***************************************************************************/
 #include <iostream>
 #include <iomanip>
+#include <cstdlib>
+#include <cstring>
 #include <string>
 #include "libofx.h"
 #include <stdio.h>		/* for printf() */
